.. _changelog:

:app:`Pyramid` Change History
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. include:: ../CHANGES.rst

.. include:: ../HISTORY.rst

:mod:`repoze.bfg` Change History (previous name for Pyramid)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. include:: ../BFG_HISTORY.rst
